class Constants:
    COLOURS = {
        "pastel": {  # Created as (20% saturation, 60% value) for each colour
            "red": ("#FFCCCC", "#990000"),
            "orange": ("#FFE0CC", "#993D00"),
            "yellow": ("#FFF6CC", "#997F00"),
            "green": ("#DBFFCC", "#2D9900"),
            "blue": ("#CCE9FF", "#005999"),
            "purple": ("#EECCFF", "#660099"),
        },
        "greyscale": {
            "grey": ("#E5E5E5", "#4C4C4C")
        },
    }
